@@ -75,8 +75,8 @@ def preprocessing_training_common(df, config, industry_dictionary, state_diction
     # Create Company years column
     df = devutils.create_company_years_column( df=df )
 
-    for days in config['days_to_define_new_position']:
-        df = devutils.create_new_position_flag(df=df, days=days)
+    # for days in config['days_to_define_new_position']:
+    #     df = devutils.create_new_position_flag(df=df, days=days)
 
     # Create new seniorities and the rest go to "other"
     df = devutils.fill_seniority_column( df=df )
@@ -218,9 +218,9 @@ def preprocessing_preleads(df,industry_dictionary,state_dictionary,mx_bv_diction
     cols_to_transform= ["QEmployeesOnLinkedIn","CompanyFollowers","LeadFollowers"]
     df_preleads_clean=devutils.log_transformation(df_preleads_clean,columns=cols_to_transform)
 
-    days_list = [60,90,120]
-    for day in days_list:
-        df_preleads_clean= devutils.create_new_position_flag(df=df_preleads_clean,days=day)
+    # days_list = [60,90,120]
+    # for day in days_list:
+    #     df_preleads_clean= devutils.create_new_position_flag(df=df_preleads_clean,days=day)
 
     # Dropping unused variables ( In this Case: delete also target columns)
     cols_to_drop = ["PreviousStatus","MXType", "DaysSincePositionStart", "Size",'kw_key','Title','LeadConnections','Specialties','Technologies','BV','IDEmailStatus','Ranking',"Rating",'MonthStatus']
