@@ -136,7 +136,7 @@ def clean_rows_with_na(df,cols_to_clean_na):
             logger.info(f"NAs in {col}: {nas_sum}")
             df = df[df[col].notna()]
     nrows_post = df.shape[0]
-    percentage_eliminated = (nrows_pre - nrows_post) / nrows_pre * 100
+    percentage_eliminated = (nrows_pre - nrows_post) / (nrows_pre * 100 +1)
     logger.info( f" Rows after deleting rows with NA: {nrows_post}, Percentage: {percentage_eliminated}" )
 
     return df
